==> mingw-w64-clang-aarch64-kbookmarks-6.0.0-1-any.pkg.tar.zst: clangarm64/lib/cmake/KF6Bookmarks/KF6BookmarksTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::BookmarksWidgets" for configuration "Release"
set_property(TARGET KF6::BookmarksWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::BookmarksWidgets PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6BookmarksWidgets.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::ConfigWidgets;KF6::Bookmarks"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6BookmarksWidgets.dll"
  )

list(APPEND _cmake_import_check_targets KF6::BookmarksWidgets )
list(APPEND _cmake_import_check_files_for_KF6::BookmarksWidgets "${_IMPORT_PREFIX}/lib/libKF6BookmarksWidgets.dll.a" "${_IMPORT_PREFIX}/bin/libKF6BookmarksWidgets.dll" )

# Import target "KF6::Bookmarks" for configuration "Release"
set_property(TARGET KF6::Bookmarks APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::Bookmarks PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6Bookmarks.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::CoreAddons;KF6::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6Bookmarks.dll"
  )

list(APPEND _cmake_import_check_targets KF6::Bookmarks )
list(APPEND _cmake_import_check_files_for_KF6::Bookmarks "${_IMPORT_PREFIX}/lib/libKF6Bookmarks.dll.a" "${_IMPORT_PREFIX}/bin/libKF6Bookmarks.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-kbookmarks-6.13.0-1-any.pkg.tar.zst: clangarm64/lib/cmake/KF6Bookmarks/KF6BookmarksTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::BookmarksWidgets" for configuration "Release"
set_property(TARGET KF6::BookmarksWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::BookmarksWidgets PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6BookmarksWidgets.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::Bookmarks;KF6::ConfigCore;KF6::ConfigGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6BookmarksWidgets.dll"
  )

list(APPEND _cmake_import_check_targets KF6::BookmarksWidgets )
list(APPEND _cmake_import_check_files_for_KF6::BookmarksWidgets "${_IMPORT_PREFIX}/lib/libKF6BookmarksWidgets.dll.a" "${_IMPORT_PREFIX}/bin/libKF6BookmarksWidgets.dll" )

# Import target "KF6::Bookmarks" for configuration "Release"
set_property(TARGET KF6::Bookmarks APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::Bookmarks PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6Bookmarks.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::CoreAddons;KF6::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6Bookmarks.dll"
  )

list(APPEND _cmake_import_check_targets KF6::Bookmarks )
list(APPEND _cmake_import_check_files_for_KF6::Bookmarks "${_IMPORT_PREFIX}/lib/libKF6Bookmarks.dll.a" "${_IMPORT_PREFIX}/bin/libKF6Bookmarks.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
